Index: branches/2.8.x/CHANGELOG
===================================================================
--- branches/2.8.x/CHANGELOG	(revision 1843)
+++ branches/2.8.x/CHANGELOG	(revision 1844)
@@ -12,6 +12,10 @@
 ===============================================================================
 
 
+28 Dez-2012 Build 1844 Dietmar Woellbrink (Luisehahne)
+# fixed Use of undefined constant PAGE_ID in /account/forgot.php
+! change return value to boolean in user management delete.php, add.php
+! change WEBSITE_SIGNATURE to WBMAIL_SIGNATURE 
 27 Dez-2012 Build 1843 Dietmar Woellbrink (Luisehahne)
 ! trash only will be shown in sectionmanagement if more than one section exists
 ! In the server settings the renaming of the page_directory is only possible, if no page exists
Index: branches/2.8.x/wb/admin/skel/themes/htt/settings.htt
===================================================================
--- branches/2.8.x/wb/admin/skel/themes/htt/settings.htt	(revision 1843)
+++ branches/2.8.x/wb/admin/skel/themes/htt/settings.htt	(revision 1844)
@@ -584,7 +584,7 @@
 		<div class="mbox sub-row">
 	 		<label class="setting_name">{TEXT_PAGES_DIRECTORY}:</label>
 			<div class="input" >
-				<input class="{PAGES_EDIT_TYPE}" type="{PAGES_EDIT_TYPE}" name="pages_directory"{PAGES_READONLY} value="{PAGES_DIRECTORY}" />
+				<input class="{PAGES_EDIT_TYPE}" type="text" name="pages_directory"{PAGES_READONLY} value="{PAGES_DIRECTORY}" />
 			</div>
 		</div>
 
@@ -674,7 +674,7 @@
 		</div>
 		<div class="mbox sub-row">
 			<label class="setting_name">{TEXT_WEBSITE_SIGNATURE}:</label>
-			<textarea class="vert" name="website_signature" cols="50" rows="4">{WEBSITE_SIGNATURE}</textarea>
+			<textarea class="vert" name="wbmail_signature" cols="50" rows="4">{WBMAIL_SIGNATURE}</textarea>
 		</div>
 
 		<div class="mbox sub-row">
Index: branches/2.8.x/wb/admin/interface/version.php
===================================================================
--- branches/2.8.x/wb/admin/interface/version.php	(revision 1843)
+++ branches/2.8.x/wb/admin/interface/version.php	(revision 1844)
@@ -51,5 +51,5 @@
 
 // check if defined to avoid errors during installation (redirect to admin panel fails if PHP error/warnings are enabled)
 if(!defined('VERSION')) define('VERSION', '2.8.3');
-if(!defined('REVISION')) define('REVISION', '1843');
+if(!defined('REVISION')) define('REVISION', '1844');
 if(!defined('SP')) define('SP', '');
Index: branches/2.8.x/wb/admin/settings/save.php
===================================================================
--- branches/2.8.x/wb/admin/settings/save.php	(revision 1843)
+++ branches/2.8.x/wb/admin/settings/save.php	(revision 1844)
@@ -173,12 +173,12 @@
 $allow_tags_in_fields = array(
     'website_header',
     'website_footer',
-    'website_signature'
+    'wbmail_signature'
     );
 $allow_empty_values = array(
     'website_header',
     'website_footer',
-    'website_signature',
+    'wbmail_signature',
     'wysiwyg_style',
     'pages_directory',
     'page_icon_dir',
@@ -196,7 +196,7 @@
     'website_title',
     'website_description',
     'website_keywords',
-    'website_signature',
+    'wbmail_signature',
     'wysiwyg_style',
     'pages_directory',
     'page_icon_dir',
Index: branches/2.8.x/wb/admin/settings/index.php
===================================================================
--- branches/2.8.x/wb/admin/settings/index.php	(revision 1843)
+++ branches/2.8.x/wb/admin/settings/index.php	(revision 1844)
@@ -34,7 +34,7 @@
 
 // add new values, later in upgrade-script
 $cfg = array(
-	'website_signature' => defined('WEBSITE_SIGNATURE') ? WEBSITE_SIGNATURE : '',
+	'wbmail_signature' => defined('WBMAIL_SIGNATURE') ? WBMAIL_SIGNATURE : '',
 	'confirmed_registration' => (defined('CONFIRMED_REGISTRATION') ? CONFIRMED_REGISTRATION : '0'),
 	'modules_upgrade_list' => (defined('MODULES_UPGRADE_LIST') ? MODULES_UPGRADE_LIST : ''),
 	);
@@ -1024,7 +1024,7 @@
 	$sPagesEditType = 'text';
 	if( $bPagesCanModify = ($database->get_one('SELECT COUNT(*) FROM `'.TABLE_PREFIX.'pages`'))!=0 ) {
 		$sReadOnly = ' readonly="readonly"';
-		$sPagesEditType = 'button';
+		$sPagesEditType = 'grey bold';
 	}
 
 	$oTpl->set_var(array(
Index: branches/2.8.x/wb/admin/users/delete.php
===================================================================
--- branches/2.8.x/wb/admin/users/delete.php	(revision 1843)
+++ branches/2.8.x/wb/admin/users/delete.php	(revision 1844)
@@ -100,7 +100,7 @@
 		}
     }
     if(isset($aActionRequest['clearmsg'])) { msgQueue::clear();  }
-    return $user_id;
+    return $bRetVal;
 }
 
 if(!isset($aActionRequest)) {
Index: branches/2.8.x/wb/admin/users/index.php
===================================================================
--- branches/2.8.x/wb/admin/users/index.php	(revision 1843)
+++ branches/2.8.x/wb/admin/users/index.php	(revision 1844)
@@ -54,11 +54,7 @@
 			case 'delete_outdated': // delete Users awaiting activation
     			$admin = new admin('Access', 'users_delete',false);
 				include($sAdminPath.'/delete.php');
-    			$output = delete_user($admin,$aActionRequest);
-
-        		if( ($msg = msgQueue::getError()) != '')
-        		{
-        		}
+    			delete_user($admin,$aActionRequest);
                 $aActionRequest['cancel_url'] = ADMIN_URL.'/access/index.php';
 				$admin = new admin('Access', 'users');
 				include($sAdminPath.'/user_list.php');
@@ -67,7 +63,7 @@
 			case 'add': // insert/update user
                 $admin = new admin('Access', 'users_add',false);
 				include($sAdminPath.'/add.php');
-    			$output = add_user($admin,$aActionRequest);
+    			add_user($admin,$aActionRequest);
                 $aActionRequest['cancel_url'] = ADMIN_URL.'/access/index.php';
 				$admin = new admin('Access', 'users');
 				include($sAdminPath.'/user_list.php');
Index: branches/2.8.x/wb/admin/users/add.php
===================================================================
--- branches/2.8.x/wb/admin/users/add.php	(revision 1843)
+++ branches/2.8.x/wb/admin/users/add.php	(revision 1844)
@@ -176,6 +176,7 @@
                     '';
             if($database->query($sql)) {
             	msgQueue::add($MESSAGE['USERS_ADDED'], true);
+		        $bRetVal = true;
             }
             if($database->is_error()) {
                 msgQueue::add( implode('<br />',explode(';',$database->get_error())) );
@@ -183,6 +184,6 @@
         } else {
         	msgQueue::add($HEADING['ADD_USER'].' '.$MESSAGE['GENERIC_NOT_COMPARE']);
 
-       }
-    }
-//
\ No newline at end of file
+		}
+		return $bRetVal;
+   }
Index: branches/2.8.x/wb/account/forgot.php
===================================================================
--- branches/2.8.x/wb/account/forgot.php	(revision 1843)
+++ branches/2.8.x/wb/account/forgot.php	(revision 1844)
@@ -28,7 +28,8 @@
 
 $wb = new frontend(false);
 
-$page_id = defined('REFERRER_ID') ? REFERRER_ID : isset($_SESSION['PAGE_ID']) ? $_SESSION['PAGE_ID'] : PAGE_ID;
+$page_id = defined('PAGE_ID') ? PAGE_ID : 0;
+$page_id = defined('REFERRER_ID') ? REFERRER_ID : isset($_SESSION['PAGE_ID']) ? $_SESSION['PAGE_ID'] : $page_id;
 
 // Required page details
 $page_description = '';
Index: branches/2.8.x/wb/install/save.php
===================================================================
--- branches/2.8.x/wb/install/save.php	(revision 1843)
+++ branches/2.8.x/wb/install/save.php	(revision 1844)
@@ -415,7 +415,7 @@
 	." (55, 'page_icon_dir', '/templates/*/title_images'),"
 	." (56, 'dev_infos', 'false'),"
 	." (57, 'groups_updated', '".time()."'),"
-	." (58, 'website_signature', ''),"
+	." (58, 'wbmail_signature', ''),"
 	." (59, 'confirmed_registration', '1'),"
 	." (60, 'page_extended', 'true'),"
 	." (61, 'modules_upgrade_list', 'news,wysiwyg,form'),"
Index: branches/2.8.x/wb/modules/news/comment.php
===================================================================
--- branches/2.8.x/wb/modules/news/comment.php	(revision 1843)
+++ branches/2.8.x/wb/modules/news/comment.php	(revision 1844)
@@ -18,8 +18,7 @@
 // Include config file
 require('../../config.php');
 require_once(WB_PATH.'/framework/class.wb.php');
-$wb = new wb;
-
+if( !(isset($wb) && is_object($wb)) ) { $wb = new wb(); }
 // Check if there is a post id
 // $post_id = $wb->checkIDKEY('post_id', false, 'GET');
 

Index: branches/2.8.x/wb/upgrade-script.php
===================================================================
--- branches/2.8.x/wb/upgrade-script.php	(revision 1843)
+++ branches/2.8.x/wb/upgrade-script.php	(revision 1844)
@@ -515,11 +515,11 @@
     $aDebugMessage[] = (db_update_key_value( 'settings', $cfg ) ? " $OK<br />" : " $FAIL!<br />");
 
     /**********************************************************
      *  - Adding website_signature to settings table
      */
-    $aDebugMessage[] = "<span>Adding/updating website_signature to settings table</span>";
+    $aDebugMessage[] = "<span>Adding/updating wbmail_signature to settings table</span>";
     $cfg = array(
-    	'website_signature' => (defined('WEBSITE_SIGNATURE') ? WEBSITE_SIGNATURE : '')
+    	'wbmail_signature' => (defined('WBMAIL_SIGNATURE') ? WBMAIL_SIGNATURE : '')
     );
 
     $aDebugMessage[] = (db_update_key_value( 'settings', $cfg ) ? " $OK<br />" : " $FAIL!<br />");
@@ -515,11 +515,11 @@
 
     /**********************************************************
-     *  - Adding website_signature to settings table
+     *  - Adding wbmail_signature to settings table
      */